@@ -235,8 +235,26 @@ def InitStartMeasurement():
 #        else: #faster in demo mode
 #            app.timer_GetData.start(data.interval/10) 
     
+    
+    
+    
+    if(data.AlarmIsSet==True): 
+        Now=int(strftime("%H", time.localtime()))*3600+int(strftime("%M", time.localtime()))*60 #nows h+m in secs
+        alarm=int(data.AlarmHour)*3600+int(data.AlarmMinute)*60 #alarm h+m in secs
+        alarmdiff=alarm-Now #difference
+        if(alarmdiff<0):  #set to tomorrow if time already is elapsed today
+            alarmdiff=alarmdiff+86400
+            data.AlarmDate=strftime("%d-%m-%Y", time.localtime(time.mktime(time.localtime())+86400))
+        else: #today
+            data.AlarmDate=strftime("%d-%m-%Y", time.localtime())
+        data.AlarmTimeSec=data.StartTimeSec+alarmdiff
+        print "Alarm will be at the "+data.AlarmDate+" "+str(data.AlarmHour)+":"+str(data.AlarmMinute)+", in:", str(alarmdiff),  "seconds (timestamp "+str(data.AlarmTimeSec)+"). We have now timestamp "+str(data.StartTimeSec)
+   
+        InitAlarm()
+    
+    
     StartLogfile(data.interval)
-    if(data.AlarmIsSet==True): InitAlarm()
+#    if(data.AlarmIsSet==True): 
     
 #    TimerLoop() #first run
    
@@ -1205,14 +1223,18 @@ class frmAlarmTimeWindow(QMainWindow):
         s="The Alarm will then go off sometimes during the time window (as soon as you move more), but latest at the set alarm time."
         self.ui.lblNote.setText(s)
 
+
+
+
     def SetAlarm(self):
         global RecordWindowGraph
         print "Set Alarm"
         data.QuickMode=0 #run in normal mode
         
-        RecordWindowGraph = RecordWindowCanvas(RecordWindow)
-        InitStartMeasurement()
+        data.AlarmIsSet=True
         
+        RecordWindowGraph = RecordWindowCanvas(RecordWindow)
+                
         try:
             data.AlarmHour=int(self.ui.lstAlarmHour.currentItem().text())
             data.AlarmMinute=int(self.ui.lstAlarmMinute.currentItem().text())
@@ -1221,24 +1243,26 @@ class frmAlarmTimeWindow(QMainWindow):
             config.set('main', 'AlarmMinute', str(data.AlarmMinute))  
             config.set('main', 'AlarmTimeWindow', str(data.AlarmTimeWindow))  
         except: #If nothing selected (workaround)
-#            data.AlarmHour=7
-#            data.AlarmMinute=0
+            data.AlarmHour=7
+            data.AlarmMinute=0
             print "Selected time not valid, use default:",  data.AlarmHour, ":", data.AlarmMinute
 
         
+        InitStartMeasurement()
         
-        Now=int(strftime("%H", time.localtime()))*3600+int(strftime("%M", time.localtime()))*60 #nows h+m in secs
-        alarm=int(data.AlarmHour)*3600+int(data.AlarmMinute)*60 #alarm h+m in secs
-        alarmdiff=alarm-Now #difference
-        if(alarmdiff<0):  #set to tomorrow if time already is elapsed today
-            alarmdiff=alarmdiff+86400
-            data.AlarmDate=strftime("%d-%m-%Y", time.localtime(time.mktime(time.localtime())+86400))
-        else: #today
-            data.AlarmDate=strftime("%d-%m-%Y", time.localtime())
-        data.AlarmTimeSec=data.StartTimeSec+alarmdiff
-        print "Alarm will be at the "+data.AlarmDate+" "+str(data.AlarmHour)+":"+str(data.AlarmMinute)+", in:", str(alarmdiff),  "seconds (timestamp "+str(data.AlarmTimeSec)+"). We have now timestamp "+str(data.StartTimeSec)
+#        Now=int(strftime("%H", time.localtime()))*3600+int(strftime("%M", time.localtime()))*60 #nows h+m in secs
+#        alarm=int(data.AlarmHour)*3600+int(data.AlarmMinute)*60 #alarm h+m in secs
+#        alarmdiff=alarm-Now #difference
+#        if(alarmdiff<0):  #set to tomorrow if time already is elapsed today
+#            alarmdiff=alarmdiff+86400
+#            data.AlarmDate=strftime("%d-%m-%Y", time.localtime(time.mktime(time.localtime())+86400))
+#        else: #today
+#            data.AlarmDate=strftime("%d-%m-%Y", time.localtime())
+#        data.AlarmTimeSec=data.StartTimeSec+alarmdiff
+#        print "Alarm will be at the "+data.AlarmDate+" "+str(data.AlarmHour)+":"+str(data.AlarmMinute)+", in:", str(alarmdiff),  "seconds (timestamp "+str(data.AlarmTimeSec)+"). We have now timestamp "+str(data.StartTimeSec)
 
         
+        
 #        if(data.demo==0): #We are on a N900
         DeleteAlarm() #delete old alarm if existing
         SetAlarm(data.AlarmHour,  data.AlarmMinute) #set alarm for the last possible time
@@ -1246,6 +1270,9 @@ class frmAlarmTimeWindow(QMainWindow):
 #        else:
 #            print "Can not set alarm, Maemo interface not available"
         
+#        data.AlarmIsSet=True
+        
+        
         RecordWindow.show()
         AlarmTimeWindow.hide()
 #        InitStartMeasurement()
