@@ -179,10 +179,11 @@ def OpenLogFile():
             data.AlarmTimeSec=time.mktime(time.strptime(data.AlarmDate+" "+str(data.AlarmHour)+":"+str(data.AlarmMinute), "%d-%m-%Y %H:%M"))
             
             print "Header Alarm time:",  data.AlarmHour,  ":",  data.AlarmMinute,  "AlarmTimeWindow:",  data.AlarmTimeWindow
+            data.AlarmIsSet=True
         else:
-            data.AlarmHour=-1
-            data.AlarmMinute=-1      
-            
+#            data.AlarmHour=-1
+#            data.AlarmMinute=-1      
+            data.AlarmIsSet=False
             
             
         
