@@ -286,12 +286,15 @@ def showGraph(self,  QtGui):
 
         # ##############################################
         #ALARM VISUALISATION
-        if(data.AlarmHour>-1 and  data.AlarmMinute>-1 and data.QuickMode==0): #we are recording normaly and an alarm is set, or we loaded a record with set alarm
+#        print data.AlarmHour,  data.AlarmMinute,  data.QuickMode
+#        if(data.AlarmHour>-1 and  data.AlarmMinute>-1 and data.QuickMode==0): #we are recording normaly and an alarm is set, or we loaded a record with set alarm
+        if(data.AlarmIsSet==True and data.QuickMode==0): #we are recording normaly and an alarm is set, or we loaded a record with set alarm
 #            timediff=(data.AlarmTimeSec - (data.StartTimeSec+data.DelayStartTime)) #diff until alarm
             timediff=(data.AlarmTimeSec - data.StartTimeSec) #diff until alarm
             t=(data.interval*data.value_smoothing)/1000
 #            print data.interval,  data.value_smoothing,  t,  data.StartTimeSec
             IndexAlarm=int(timediff/t)
+#            print "IndexAlarm:",  IndexAlarm,  timediff,  t,  data.AlarmTimeSec,  data.StartTimeSec
 #            timediff2=(data.AlarmTimeSec - (data.StartTimeSec+data.DelayStartTime)) - data.AlarmTimeWindow*60 #diff until alarm - AlarmTimeWindow
             timediff2=(data.AlarmTimeSec - data.StartTimeSec) - data.AlarmTimeWindow*60 #diff until alarm - AlarmTimeWindow
             IndexAlarm2=int(timediff2/t)
@@ -309,6 +312,7 @@ def showGraph(self,  QtGui):
             x1=(IndexAlarm-data.GraphStart)/Xscale #set alarm position in graph 
             x0=(IndexAlarm2-data.GraphStart)/Xscale #AlarmTimeWindow position in graph
             
+#            print x0,  x1 ,  IndexAlarm,  data.GraphStart 
             #Draw alarm set point
             if(IndexAlarm>=data.GraphStart and IndexAlarm<=(data.GraphStart+755*Xscale)): #show in graph
 #                print "Set Alarm:",  x1
@@ -406,7 +410,7 @@ def SetAlarm(hour,  minute):
     m=int(strftime("%M", time.localtime()))
 #    alarmdiff=getSecondsUntilAlarm(h, m)
     now=h*3600+m*60
-    al=int(data.AlarmHour)*3600+int(data.AlarmMinute)*60
+    al=int(hour)*3600+int(minute)*60
     alarmdiff=al-now
     if(alarmdiff<0):  #set to tomorrow if time already is elapsed today
         alarmdiff=alarmdiff+86400
@@ -465,6 +469,10 @@ def InitAlarm():
 #    if(data.arrDataIndex==0 and data.AlarmIsSet==True): #do only on first time and if alarm is set
 #        print "first loop run",  data.arrData[0][0]
 #    t=string.split(data.arrData[0][0],  ":")
+
+    print "Initialize Alarm visualisation"
+
+#    print "StartTime:",  data.StartTime, "Alarm:",   data.AlarmHour,  data.AlarmMinute
     now=int(strftime("%H", data.StartTime))*3600+int(strftime("%M", data.StartTime))*60
     al=int(data.AlarmHour)*3600+int(data.AlarmMinute)*60
     alarmdiff=al-now
@@ -506,7 +514,7 @@ def ProcessAlarm():
             m=int(strftime("%M", time.localtime()))
 #            if(data.demo==0): # we are on a N900
             DeleteAlarm() #delete old alarm if existing
-            print "* Set new Alarm to current time"
+            print "* Set new Alarm to current time:",  h,  ":",  m
             SetAlarm(h,  m) #set alarm to go off now
 #            else: 
 #                print "Can not set alarm off, Maemo interface not available"
